==> jc-1.4.0.tar.gz: java/awt/geom/Point2D__24Float.h <==
// public class java.awt.geom.Point2D$Float

// class file dependencies
// @dep_class 7b4d9094dbdc54ce java_awt_geom_Point2D
// @dep_class f16fcafe3bbe42f3 java_awt_geom_Point2D__24Float
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Point2D

#include "java/awt/geom/Point2D.h"

#ifndef _JC_java_awt_geom_Point2D__24Float_H_
#define _JC_java_awt_geom_Point2D__24Float_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_Point2D__24Float$sub_refs	_jc_java_awt_geom_Point2D__24Float$sub_refs;
typedef struct _jc_java_awt_geom_Point2D__24Float$sub_nonrefs	_jc_java_awt_geom_Point2D__24Float$sub_nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Float$refs	_jc_java_awt_geom_Point2D__24Float$refs;
typedef struct _jc_java_awt_geom_Point2D__24Float$nonrefs	_jc_java_awt_geom_Point2D__24Float$nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Float$object	_jc_java_awt_geom_Point2D__24Float$object;

typedef const struct _jc_java_awt_geom_Point2D__24Float$vmethods	_jc_java_awt_geom_Point2D__24Float$vmethods;
typedef const struct _jc_java_awt_geom_Point2D__24Float$vtable	_jc_java_awt_geom_Point2D__24Float$vtable;
typedef const struct _jc_java_awt_geom_Point2D__24Float$vtype	_jc_java_awt_geom_Point2D__24Float$vtype;

// Constructors
extern void _jc_java_awt_geom_Point2D__24Float$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
extern void _jc_java_awt_geom_Point2D__24Float$method$_init$d8295d5efb7fb530(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat);

// Virtual methods
extern jdouble _jc_java_awt_geom_Point2D__24Float$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
extern jdouble _jc_java_awt_geom_Point2D__24Float$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
extern void _jc_java_awt_geom_Point2D__24Float$method$setLocation$689557087e3caf93(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jdouble, jdouble);
extern void _jc_java_awt_geom_Point2D__24Float$method$setLocation$96703cd3d74db329(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat);
extern struct _jc_java_lang_String$object *_jc_java_awt_geom_Point2D__24Float$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$setLocation$689557087e3caf93;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$setLocation$96703cd3d74db329;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_geom_Point2D__24Float$vmethods {
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
	void	(*setLocation$689557087e3caf93)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jdouble, jdouble);
	void	(*setLocation$96703cd3d74db329)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *);
};

// Vtable
struct _jc_java_awt_geom_Point2D__24Float$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Point2D$vmethods	java_awt_geom_Point2D;
	_jc_java_awt_geom_Point2D__24Float$vmethods	java_awt_geom_Point2D__24Float;
};

// Vtype
struct _jc_java_awt_geom_Point2D__24Float$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Point2D__24Float$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Float$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Float$refs {
    _jc_java_awt_geom_Point2D__24Float$sub_refs	java_awt_geom_Point2D__24Float;
    _jc_java_awt_geom_Point2D$sub_refs	java_awt_geom_Point2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Float$sub_nonrefs {
	jfloat	x;
	jfloat	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Float$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Point2D$sub_nonrefs	java_awt_geom_Point2D;
    _jc_java_awt_geom_Point2D__24Float$sub_nonrefs	java_awt_geom_Point2D__24Float;
};

// Object instance structure
struct _jc_java_awt_geom_Point2D__24Float$object {
	_jc_java_awt_geom_Point2D__24Float$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Point2D__24Float$vtype	*vtype;
	_jc_java_awt_geom_Point2D__24Float$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Point2D__24Float$vtype _jc_java_awt_geom_Point2D__24Float$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Point2D__24Float, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Point2D__24Float$class_object;

#endif	/* _JC_java_awt_geom_Point2D__24Float_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Point2D__24Float.h <==
// public class java.awt.geom.Point2D$Float

// class file dependencies
// @dep_class 7b4d9094dbdc54ce java_awt_geom_Point2D
// @dep_class f16fcafe3bbe42f3 java_awt_geom_Point2D__24Float
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Point2D

#include "java/awt/geom/Point2D.h"

#ifndef _JC_java_awt_geom_Point2D__24Float_H_
#define _JC_java_awt_geom_Point2D__24Float_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_geom_Point2D__24Float$sub_refs	_jc_java_awt_geom_Point2D__24Float$sub_refs;
typedef struct _jc_java_awt_geom_Point2D__24Float$sub_nonrefs	_jc_java_awt_geom_Point2D__24Float$sub_nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Float$refs	_jc_java_awt_geom_Point2D__24Float$refs;
typedef struct _jc_java_awt_geom_Point2D__24Float$nonrefs	_jc_java_awt_geom_Point2D__24Float$nonrefs;
typedef struct _jc_java_awt_geom_Point2D__24Float$object	_jc_java_awt_geom_Point2D__24Float$object;

typedef const struct _jc_java_awt_geom_Point2D__24Float$vmethods	_jc_java_awt_geom_Point2D__24Float$vmethods;
typedef const struct _jc_java_awt_geom_Point2D__24Float$vtable	_jc_java_awt_geom_Point2D__24Float$vtable;
typedef const struct _jc_java_awt_geom_Point2D__24Float$vtype	_jc_java_awt_geom_Point2D__24Float$vtype;

// Constructors
extern void _jc_java_awt_geom_Point2D__24Float$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Point2D__24Float$method$_init$d8295d5efb7fb530(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern jdouble _jc_java_awt_geom_Point2D__24Float$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Point2D__24Float$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Point2D__24Float$method$setLocation$689557087e3caf93(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jdouble, jdouble) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Point2D__24Float$method$setLocation$96703cd3d74db329(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_geom_Point2D__24Float$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$setLocation$689557087e3caf93;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$setLocation$96703cd3d74db329;
extern _jc_method _jc_java_awt_geom_Point2D__24Float$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_geom_Point2D__24Float$vmethods {
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
	void	(*setLocation$689557087e3caf93)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jdouble, jdouble) _JC_JCNI_ATTR;
	void	(*setLocation$96703cd3d74db329)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *, jfloat, jfloat) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_geom_Point2D__24Float$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Point2D__24Float$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_Point2D$vmethods	java_awt_geom_Point2D;
	_jc_java_awt_geom_Point2D__24Float$vmethods	java_awt_geom_Point2D__24Float;
};

// Vtype
struct _jc_java_awt_geom_Point2D__24Float$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Point2D__24Float$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Float$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Float$refs {
    _jc_java_awt_geom_Point2D__24Float$sub_refs	java_awt_geom_Point2D__24Float;
    _jc_java_awt_geom_Point2D$sub_refs	java_awt_geom_Point2D;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Point2D__24Float$sub_nonrefs {
	jfloat	x;
	jfloat	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Point2D__24Float$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_Point2D$sub_nonrefs	java_awt_geom_Point2D;
    _jc_java_awt_geom_Point2D__24Float$sub_nonrefs	java_awt_geom_Point2D__24Float;
};

// Object instance structure
struct _jc_java_awt_geom_Point2D__24Float$object {
	_jc_java_awt_geom_Point2D__24Float$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Point2D__24Float$vtype	*vtype;
	_jc_java_awt_geom_Point2D__24Float$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Point2D__24Float$vtype _jc_java_awt_geom_Point2D__24Float$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Point2D__24Float, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Point2D__24Float$class_object;

#endif	/* _JC_java_awt_geom_Point2D__24Float_H_ */
